# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["ListObjectsResponse", "Content"]


class Content(BaseModel):
    key: Optional[str] = FieldInfo(alias="Key", default=None)

    last_modified: Optional[datetime] = FieldInfo(alias="LastModified", default=None)

    size: Optional[float] = FieldInfo(alias="Size", default=None)


class ListObjectsResponse(BaseModel):
    contents: Optional[List[Content]] = FieldInfo(alias="Contents", default=None)

    name: Optional[str] = FieldInfo(alias="Name", default=None)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import TypedDict

__all__ = ["ActionUnmuteParams"]


class ActionUnmuteParams(TypedDict, total=False):
    call_control_ids: List[str]
    """List of unique identifiers and tokens for controlling the call.

    Enter each call control ID to be unmuted. When empty all participants will be
    unmuted.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import global_ip_usage_retrieve_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.global_ip_usage_retrieve_response import GlobalIPUsageRetrieveResponse

__all__ = ["GlobalIPUsageResource", "AsyncGlobalIPUsageResource"]


class GlobalIPUsageResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> GlobalIPUsageResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return GlobalIPUsageResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> GlobalIPUsageResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return GlobalIPUsageResourceWithStreamingResponse(self)

    def retrieve(
        self,
        *,
        filter: global_ip_usage_retrieve_params.Filter | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> GlobalIPUsageRetrieveResponse:
        """
        Global IP Usage Metrics

        Args:
          filter:
              Consolidated filter parameter (deepObject style). Originally:
              filter[global_ip_id][in]

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/global_ip_usage",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"filter": filter}, global_ip_usage_retrieve_params.GlobalIPUsageRetrieveParams),
            ),
            cast_to=GlobalIPUsageRetrieveResponse,
        )


class AsyncGlobalIPUsageResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncGlobalIPUsageResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return AsyncGlobalIPUsageResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncGlobalIPUsageResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return AsyncGlobalIPUsageResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        *,
        filter: global_ip_usage_retrieve_params.Filter | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> GlobalIPUsageRetrieveResponse:
        """
        Global IP Usage Metrics

        Args:
          filter:
              Consolidated filter parameter (deepObject style). Originally:
              filter[global_ip_id][in]

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/global_ip_usage",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"filter": filter}, global_ip_usage_retrieve_params.GlobalIPUsageRetrieveParams
                ),
            ),
            cast_to=GlobalIPUsageRetrieveResponse,
        )


class GlobalIPUsageResourceWithRawResponse:
    def __init__(self, global_ip_usage: GlobalIPUsageResource) -> None:
        self._global_ip_usage = global_ip_usage

        self.retrieve = to_raw_response_wrapper(
            global_ip_usage.retrieve,
        )


class AsyncGlobalIPUsageResourceWithRawResponse:
    def __init__(self, global_ip_usage: AsyncGlobalIPUsageResource) -> None:
        self._global_ip_usage = global_ip_usage

        self.retrieve = async_to_raw_response_wrapper(
            global_ip_usage.retrieve,
        )


class GlobalIPUsageResourceWithStreamingResponse:
    def __init__(self, global_ip_usage: GlobalIPUsageResource) -> None:
        self._global_ip_usage = global_ip_usage

        self.retrieve = to_streamed_response_wrapper(
            global_ip_usage.retrieve,
        )


class AsyncGlobalIPUsageResourceWithStreamingResponse:
    def __init__(self, global_ip_usage: AsyncGlobalIPUsageResource) -> None:
        self._global_ip_usage = global_ip_usage

        self.retrieve = async_to_streamed_response_wrapper(
            global_ip_usage.retrieve,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import Required, TypedDict

__all__ = ["RcListBulkCapabilitiesParams"]


class RcListBulkCapabilitiesParams(TypedDict, total=False):
    agent_id: Required[str]
    """RCS Agent ID"""

    phone_numbers: Required[List[str]]
    """List of phone numbers to check"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from telnyx import Telnyx, AsyncTelnyx
from tests.utils import assert_matches_type
from telnyx.types.porting_orders import (
    AssociatedPhoneNumberListResponse,
    AssociatedPhoneNumberCreateResponse,
    AssociatedPhoneNumberDeleteResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestAssociatedPhoneNumbers:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create(self, client: Telnyx) -> None:
        associated_phone_number = client.porting_orders.associated_phone_numbers.create(
            porting_order_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            action="keep",
            phone_number_range={},
        )
        assert_matches_type(AssociatedPhoneNumberCreateResponse, associated_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create_with_all_params(self, client: Telnyx) -> None:
        associated_phone_number = client.porting_orders.associated_phone_numbers.create(
            porting_order_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            action="keep",
            phone_number_range={
                "end_at": "+441234567899",
                "start_at": "+441234567890",
            },
        )
        assert_matches_type(AssociatedPhoneNumberCreateResponse, associated_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: Telnyx) -> None:
        response = client.porting_orders.associated_phone_numbers.with_raw_response.create(
            porting_order_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            action="keep",
            phone_number_range={},
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        associated_phone_number = response.parse()
        assert_matches_type(AssociatedPhoneNumberCreateResponse, associated_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: Telnyx) -> None:
        with client.porting_orders.associated_phone_numbers.with_streaming_response.create(
            porting_order_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            action="keep",
            phone_number_range={},
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            associated_phone_number = response.parse()
            assert_matches_type(AssociatedPhoneNumberCreateResponse, associated_phone_number, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_create(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `porting_order_id` but received ''"):
            client.porting_orders.associated_phone_numbers.with_raw_response.create(
                porting_order_id="",
                action="keep",
                phone_number_range={},
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list(self, client: Telnyx) -> None:
        associated_phone_number = client.porting_orders.associated_phone_numbers.list(
            porting_order_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(AssociatedPhoneNumberListResponse, associated_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_with_all_params(self, client: Telnyx) -> None:
        associated_phone_number = client.porting_orders.associated_phone_numbers.list(
            porting_order_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            filter={
                "action": "keep",
                "phone_number": "+441234567890",
            },
            page={
                "number": 1,
                "size": 1,
            },
            sort={"value": "-created_at"},
        )
        assert_matches_type(AssociatedPhoneNumberListResponse, associated_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Telnyx) -> None:
        response = client.porting_orders.associated_phone_numbers.with_raw_response.list(
            porting_order_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        associated_phone_number = response.parse()
        assert_matches_type(AssociatedPhoneNumberListResponse, associated_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Telnyx) -> None:
        with client.porting_orders.associated_phone_numbers.with_streaming_response.list(
            porting_order_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            associated_phone_number = response.parse()
            assert_matches_type(AssociatedPhoneNumberListResponse, associated_phone_number, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_list(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `porting_order_id` but received ''"):
            client.porting_orders.associated_phone_numbers.with_raw_response.list(
                porting_order_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_delete(self, client: Telnyx) -> None:
        associated_phone_number = client.porting_orders.associated_phone_numbers.delete(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            porting_order_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(AssociatedPhoneNumberDeleteResponse, associated_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_delete(self, client: Telnyx) -> None:
        response = client.porting_orders.associated_phone_numbers.with_raw_response.delete(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            porting_order_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        associated_phone_number = response.parse()
        assert_matches_type(AssociatedPhoneNumberDeleteResponse, associated_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_delete(self, client: Telnyx) -> None:
        with client.porting_orders.associated_phone_numbers.with_streaming_response.delete(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            porting_order_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            associated_phone_number = response.parse()
            assert_matches_type(AssociatedPhoneNumberDeleteResponse, associated_phone_number, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_delete(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `porting_order_id` but received ''"):
            client.porting_orders.associated_phone_numbers.with_raw_response.delete(
                id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                porting_order_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.porting_orders.associated_phone_numbers.with_raw_response.delete(
                id="",
                porting_order_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )


class TestAsyncAssociatedPhoneNumbers:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncTelnyx) -> None:
        associated_phone_number = await async_client.porting_orders.associated_phone_numbers.create(
            porting_order_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            action="keep",
            phone_number_range={},
        )
        assert_matches_type(AssociatedPhoneNumberCreateResponse, associated_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncTelnyx) -> None:
        associated_phone_number = await async_client.porting_orders.associated_phone_numbers.create(
            porting_order_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            action="keep",
            phone_number_range={
                "end_at": "+441234567899",
                "start_at": "+441234567890",
            },
        )
        assert_matches_type(AssociatedPhoneNumberCreateResponse, associated_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.porting_orders.associated_phone_numbers.with_raw_response.create(
            porting_order_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            action="keep",
            phone_number_range={},
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        associated_phone_number = await response.parse()
        assert_matches_type(AssociatedPhoneNumberCreateResponse, associated_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncTelnyx) -> None:
        async with async_client.porting_orders.associated_phone_numbers.with_streaming_response.create(
            porting_order_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            action="keep",
            phone_number_range={},
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            associated_phone_number = await response.parse()
            assert_matches_type(AssociatedPhoneNumberCreateResponse, associated_phone_number, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_create(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `porting_order_id` but received ''"):
            await async_client.porting_orders.associated_phone_numbers.with_raw_response.create(
                porting_order_id="",
                action="keep",
                phone_number_range={},
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncTelnyx) -> None:
        associated_phone_number = await async_client.porting_orders.associated_phone_numbers.list(
            porting_order_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(AssociatedPhoneNumberListResponse, associated_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncTelnyx) -> None:
        associated_phone_number = await async_client.porting_orders.associated_phone_numbers.list(
            porting_order_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            filter={
                "action": "keep",
                "phone_number": "+441234567890",
            },
            page={
                "number": 1,
                "size": 1,
            },
            sort={"value": "-created_at"},
        )
        assert_matches_type(AssociatedPhoneNumberListResponse, associated_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.porting_orders.associated_phone_numbers.with_raw_response.list(
            porting_order_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        associated_phone_number = await response.parse()
        assert_matches_type(AssociatedPhoneNumberListResponse, associated_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncTelnyx) -> None:
        async with async_client.porting_orders.associated_phone_numbers.with_streaming_response.list(
            porting_order_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            associated_phone_number = await response.parse()
            assert_matches_type(AssociatedPhoneNumberListResponse, associated_phone_number, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_list(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `porting_order_id` but received ''"):
            await async_client.porting_orders.associated_phone_numbers.with_raw_response.list(
                porting_order_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_delete(self, async_client: AsyncTelnyx) -> None:
        associated_phone_number = await async_client.porting_orders.associated_phone_numbers.delete(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            porting_order_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(AssociatedPhoneNumberDeleteResponse, associated_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.porting_orders.associated_phone_numbers.with_raw_response.delete(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            porting_order_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        associated_phone_number = await response.parse()
        assert_matches_type(AssociatedPhoneNumberDeleteResponse, associated_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncTelnyx) -> None:
        async with async_client.porting_orders.associated_phone_numbers.with_streaming_response.delete(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            porting_order_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            associated_phone_number = await response.parse()
            assert_matches_type(AssociatedPhoneNumberDeleteResponse, associated_phone_number, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_delete(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `porting_order_id` but received ''"):
            await async_client.porting_orders.associated_phone_numbers.with_raw_response.delete(
                id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                porting_order_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.porting_orders.associated_phone_numbers.with_raw_response.delete(
                id="",
                porting_order_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["ClientGetObjectParams"]


class ClientGetObjectParams(TypedDict, total=False):
    bucket_name: Required[Annotated[str, PropertyInfo(alias="bucketName")]]

    upload_id: Annotated[str, PropertyInfo(alias="uploadId")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Optional
from typing_extensions import Literal

import httpx

from ...types import (
    messaging_profile_list_params,
    messaging_profile_create_params,
    messaging_profile_update_params,
    messaging_profile_list_short_codes_params,
    messaging_profile_list_phone_numbers_params,
)
from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from .autoresp_configs import (
    AutorespConfigsResource,
    AsyncAutorespConfigsResource,
    AutorespConfigsResourceWithRawResponse,
    AsyncAutorespConfigsResourceWithRawResponse,
    AutorespConfigsResourceWithStreamingResponse,
    AsyncAutorespConfigsResourceWithStreamingResponse,
)
from ...types.number_pool_settings_param import NumberPoolSettingsParam
from ...types.url_shortener_settings_param import URLShortenerSettingsParam
from ...types.messaging_profile_list_response import MessagingProfileListResponse
from ...types.messaging_profile_create_response import MessagingProfileCreateResponse
from ...types.messaging_profile_delete_response import MessagingProfileDeleteResponse
from ...types.messaging_profile_update_response import MessagingProfileUpdateResponse
from ...types.messaging_profile_retrieve_response import MessagingProfileRetrieveResponse
from ...types.messaging_profile_list_short_codes_response import MessagingProfileListShortCodesResponse
from ...types.messaging_profile_list_phone_numbers_response import MessagingProfileListPhoneNumbersResponse

__all__ = ["MessagingProfilesResource", "AsyncMessagingProfilesResource"]


class MessagingProfilesResource(SyncAPIResource):
    @cached_property
    def autoresp_configs(self) -> AutorespConfigsResource:
        return AutorespConfigsResource(self._client)

    @cached_property
    def with_raw_response(self) -> MessagingProfilesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return MessagingProfilesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> MessagingProfilesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return MessagingProfilesResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        name: str,
        whitelisted_destinations: List[str],
        alpha_sender: Optional[str] | NotGiven = NOT_GIVEN,
        daily_spend_limit: str | NotGiven = NOT_GIVEN,
        daily_spend_limit_enabled: bool | NotGiven = NOT_GIVEN,
        enabled: bool | NotGiven = NOT_GIVEN,
        mms_fall_back_to_sms: bool | NotGiven = NOT_GIVEN,
        mms_transcoding: bool | NotGiven = NOT_GIVEN,
        number_pool_settings: Optional[NumberPoolSettingsParam] | NotGiven = NOT_GIVEN,
        url_shortener_settings: Optional[URLShortenerSettingsParam] | NotGiven = NOT_GIVEN,
        webhook_api_version: Literal["1", "2", "2010-04-01"] | NotGiven = NOT_GIVEN,
        webhook_failover_url: Optional[str] | NotGiven = NOT_GIVEN,
        webhook_url: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MessagingProfileCreateResponse:
        """
        Create a messaging profile

        Args:
          name: A user friendly name for the messaging profile.

          whitelisted_destinations: Destinations to which the messaging profile is allowed to send. The elements in
              the list must be valid ISO 3166-1 alpha-2 country codes. If set to `["*"]` all
              destinations will be allowed.

          alpha_sender: The alphanumeric sender ID to use when sending to destinations that require an
              alphanumeric sender ID.

          daily_spend_limit: The maximum amount of money (in USD) that can be spent by this profile before
              midnight UTC.

          daily_spend_limit_enabled: Whether to enforce the value configured by `daily_spend_limit`.

          enabled: Specifies whether the messaging profile is enabled or not.

          mms_fall_back_to_sms: enables SMS fallback for MMS messages.

          mms_transcoding: enables automated resizing of MMS media.

          number_pool_settings: Number Pool allows you to send messages from a pool of numbers of different
              types, assigning weights to each type. The pool consists of all the long code
              and toll free numbers assigned to the messaging profile.

              To disable this feature, set the object field to `null`.

          url_shortener_settings: The URL shortener feature allows automatic replacement of URLs that were
              generated using a public URL shortener service. Some examples include bit.do,
              bit.ly, goo.gl, ht.ly, is.gd, ow.ly, rebrand.ly, t.co, tiny.cc, and tinyurl.com.
              Such URLs are replaced with with links generated by Telnyx. The use of custom
              links can improve branding and message deliverability.

              To disable this feature, set the object field to `null`.

          webhook_api_version: Determines which webhook format will be used, Telnyx API v1, v2, or a legacy
              2010-04-01 format.

          webhook_failover_url: The failover URL where webhooks related to this messaging profile will be sent
              if sending to the primary URL fails.

          webhook_url: The URL where webhooks related to this messaging profile will be sent.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/messaging_profiles",
            body=maybe_transform(
                {
                    "name": name,
                    "whitelisted_destinations": whitelisted_destinations,
                    "alpha_sender": alpha_sender,
                    "daily_spend_limit": daily_spend_limit,
                    "daily_spend_limit_enabled": daily_spend_limit_enabled,
                    "enabled": enabled,
                    "mms_fall_back_to_sms": mms_fall_back_to_sms,
                    "mms_transcoding": mms_transcoding,
                    "number_pool_settings": number_pool_settings,
                    "url_shortener_settings": url_shortener_settings,
                    "webhook_api_version": webhook_api_version,
                    "webhook_failover_url": webhook_failover_url,
                    "webhook_url": webhook_url,
                },
                messaging_profile_create_params.MessagingProfileCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MessagingProfileCreateResponse,
        )

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MessagingProfileRetrieveResponse:
        """
        Retrieve a messaging profile

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/messaging_profiles/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MessagingProfileRetrieveResponse,
        )

    def update(
        self,
        id: str,
        *,
        alpha_sender: Optional[str] | NotGiven = NOT_GIVEN,
        daily_spend_limit: str | NotGiven = NOT_GIVEN,
        daily_spend_limit_enabled: bool | NotGiven = NOT_GIVEN,
        enabled: bool | NotGiven = NOT_GIVEN,
        mms_fall_back_to_sms: bool | NotGiven = NOT_GIVEN,
        mms_transcoding: bool | NotGiven = NOT_GIVEN,
        name: str | NotGiven = NOT_GIVEN,
        number_pool_settings: Optional[NumberPoolSettingsParam] | NotGiven = NOT_GIVEN,
        url_shortener_settings: Optional[URLShortenerSettingsParam] | NotGiven = NOT_GIVEN,
        v1_secret: str | NotGiven = NOT_GIVEN,
        webhook_api_version: Literal["1", "2", "2010-04-01"] | NotGiven = NOT_GIVEN,
        webhook_failover_url: Optional[str] | NotGiven = NOT_GIVEN,
        webhook_url: Optional[str] | NotGiven = NOT_GIVEN,
        whitelisted_destinations: List[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MessagingProfileUpdateResponse:
        """
        Update a messaging profile

        Args:
          alpha_sender: The alphanumeric sender ID to use when sending to destinations that require an
              alphanumeric sender ID.

          daily_spend_limit: The maximum amount of money (in USD) that can be spent by this profile before
              midnight UTC.

          daily_spend_limit_enabled: Whether to enforce the value configured by `daily_spend_limit`.

          enabled: Specifies whether the messaging profile is enabled or not.

          mms_fall_back_to_sms: enables SMS fallback for MMS messages.

          mms_transcoding: enables automated resizing of MMS media.

          name: A user friendly name for the messaging profile.

          number_pool_settings: Number Pool allows you to send messages from a pool of numbers of different
              types, assigning weights to each type. The pool consists of all the long code
              and toll free numbers assigned to the messaging profile.

              To disable this feature, set the object field to `null`.

          url_shortener_settings: The URL shortener feature allows automatic replacement of URLs that were
              generated using a public URL shortener service. Some examples include bit.do,
              bit.ly, goo.gl, ht.ly, is.gd, ow.ly, rebrand.ly, t.co, tiny.cc, and tinyurl.com.
              Such URLs are replaced with with links generated by Telnyx. The use of custom
              links can improve branding and message deliverability.

              To disable this feature, set the object field to `null`.

          v1_secret: Secret used to authenticate with v1 endpoints.

          webhook_api_version: Determines which webhook format will be used, Telnyx API v1, v2, or a legacy
              2010-04-01 format.

          webhook_failover_url: The failover URL where webhooks related to this messaging profile will be sent
              if sending to the primary URL fails.

          webhook_url: The URL where webhooks related to this messaging profile will be sent.

          whitelisted_destinations: Destinations to which the messaging profile is allowed to send. The elements in
              the list must be valid ISO 3166-1 alpha-2 country codes. If set to `["*"]`, all
              destinations will be allowed.

              This field is required if the messaging profile doesn't have it defined yet.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._patch(
            f"/messaging_profiles/{id}",
            body=maybe_transform(
                {
                    "alpha_sender": alpha_sender,
                    "daily_spend_limit": daily_spend_limit,
                    "daily_spend_limit_enabled": daily_spend_limit_enabled,
                    "enabled": enabled,
                    "mms_fall_back_to_sms": mms_fall_back_to_sms,
                    "mms_transcoding": mms_transcoding,
                    "name": name,
                    "number_pool_settings": number_pool_settings,
                    "url_shortener_settings": url_shortener_settings,
                    "v1_secret": v1_secret,
                    "webhook_api_version": webhook_api_version,
                    "webhook_failover_url": webhook_failover_url,
                    "webhook_url": webhook_url,
                    "whitelisted_destinations": whitelisted_destinations,
                },
                messaging_profile_update_params.MessagingProfileUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MessagingProfileUpdateResponse,
        )

    def list(
        self,
        *,
        filter: messaging_profile_list_params.Filter | NotGiven = NOT_GIVEN,
        page: messaging_profile_list_params.Page | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MessagingProfileListResponse:
        """
        List messaging profiles

        Args:
          filter: Consolidated filter parameter (deepObject style). Originally: filter[name]

          page: Consolidated page parameter (deepObject style). Originally: page[number],
              page[size]

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/messaging_profiles",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "filter": filter,
                        "page": page,
                    },
                    messaging_profile_list_params.MessagingProfileListParams,
                ),
            ),
            cast_to=MessagingProfileListResponse,
        )

    def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MessagingProfileDeleteResponse:
        """
        Delete a messaging profile

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._delete(
            f"/messaging_profiles/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MessagingProfileDeleteResponse,
        )

    def list_phone_numbers(
        self,
        id: str,
        *,
        page: messaging_profile_list_phone_numbers_params.Page | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MessagingProfileListPhoneNumbersResponse:
        """
        List phone numbers associated with a messaging profile

        Args:
          page: Consolidated page parameter (deepObject style). Originally: page[number],
              page[size]

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/messaging_profiles/{id}/phone_numbers",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"page": page}, messaging_profile_list_phone_numbers_params.MessagingProfileListPhoneNumbersParams
                ),
            ),
            cast_to=MessagingProfileListPhoneNumbersResponse,
        )

    def list_short_codes(
        self,
        id: str,
        *,
        page: messaging_profile_list_short_codes_params.Page | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MessagingProfileListShortCodesResponse:
        """
        List short codes associated with a messaging profile

        Args:
          page: Consolidated page parameter (deepObject style). Originally: page[number],
              page[size]

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/messaging_profiles/{id}/short_codes",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"page": page}, messaging_profile_list_short_codes_params.MessagingProfileListShortCodesParams
                ),
            ),
            cast_to=MessagingProfileListShortCodesResponse,
        )


class AsyncMessagingProfilesResource(AsyncAPIResource):
    @cached_property
    def autoresp_configs(self) -> AsyncAutorespConfigsResource:
        return AsyncAutorespConfigsResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncMessagingProfilesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return AsyncMessagingProfilesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncMessagingProfilesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return AsyncMessagingProfilesResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        name: str,
        whitelisted_destinations: List[str],
        alpha_sender: Optional[str] | NotGiven = NOT_GIVEN,
        daily_spend_limit: str | NotGiven = NOT_GIVEN,
        daily_spend_limit_enabled: bool | NotGiven = NOT_GIVEN,
        enabled: bool | NotGiven = NOT_GIVEN,
        mms_fall_back_to_sms: bool | NotGiven = NOT_GIVEN,
        mms_transcoding: bool | NotGiven = NOT_GIVEN,
        number_pool_settings: Optional[NumberPoolSettingsParam] | NotGiven = NOT_GIVEN,
        url_shortener_settings: Optional[URLShortenerSettingsParam] | NotGiven = NOT_GIVEN,
        webhook_api_version: Literal["1", "2", "2010-04-01"] | NotGiven = NOT_GIVEN,
        webhook_failover_url: Optional[str] | NotGiven = NOT_GIVEN,
        webhook_url: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MessagingProfileCreateResponse:
        """
        Create a messaging profile

        Args:
          name: A user friendly name for the messaging profile.

          whitelisted_destinations: Destinations to which the messaging profile is allowed to send. The elements in
              the list must be valid ISO 3166-1 alpha-2 country codes. If set to `["*"]` all
              destinations will be allowed.

          alpha_sender: The alphanumeric sender ID to use when sending to destinations that require an
              alphanumeric sender ID.

          daily_spend_limit: The maximum amount of money (in USD) that can be spent by this profile before
              midnight UTC.

          daily_spend_limit_enabled: Whether to enforce the value configured by `daily_spend_limit`.

          enabled: Specifies whether the messaging profile is enabled or not.

          mms_fall_back_to_sms: enables SMS fallback for MMS messages.

          mms_transcoding: enables automated resizing of MMS media.

          number_pool_settings: Number Pool allows you to send messages from a pool of numbers of different
              types, assigning weights to each type. The pool consists of all the long code
              and toll free numbers assigned to the messaging profile.

              To disable this feature, set the object field to `null`.

          url_shortener_settings: The URL shortener feature allows automatic replacement of URLs that were
              generated using a public URL shortener service. Some examples include bit.do,
              bit.ly, goo.gl, ht.ly, is.gd, ow.ly, rebrand.ly, t.co, tiny.cc, and tinyurl.com.
              Such URLs are replaced with with links generated by Telnyx. The use of custom
              links can improve branding and message deliverability.

              To disable this feature, set the object field to `null`.

          webhook_api_version: Determines which webhook format will be used, Telnyx API v1, v2, or a legacy
              2010-04-01 format.

          webhook_failover_url: The failover URL where webhooks related to this messaging profile will be sent
              if sending to the primary URL fails.

          webhook_url: The URL where webhooks related to this messaging profile will be sent.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/messaging_profiles",
            body=await async_maybe_transform(
                {
                    "name": name,
                    "whitelisted_destinations": whitelisted_destinations,
                    "alpha_sender": alpha_sender,
                    "daily_spend_limit": daily_spend_limit,
                    "daily_spend_limit_enabled": daily_spend_limit_enabled,
                    "enabled": enabled,
                    "mms_fall_back_to_sms": mms_fall_back_to_sms,
                    "mms_transcoding": mms_transcoding,
                    "number_pool_settings": number_pool_settings,
                    "url_shortener_settings": url_shortener_settings,
                    "webhook_api_version": webhook_api_version,
                    "webhook_failover_url": webhook_failover_url,
                    "webhook_url": webhook_url,
                },
                messaging_profile_create_params.MessagingProfileCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MessagingProfileCreateResponse,
        )

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MessagingProfileRetrieveResponse:
        """
        Retrieve a messaging profile

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/messaging_profiles/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MessagingProfileRetrieveResponse,
        )

    async def update(
        self,
        id: str,
        *,
        alpha_sender: Optional[str] | NotGiven = NOT_GIVEN,
        daily_spend_limit: str | NotGiven = NOT_GIVEN,
        daily_spend_limit_enabled: bool | NotGiven = NOT_GIVEN,
        enabled: bool | NotGiven = NOT_GIVEN,
        mms_fall_back_to_sms: bool | NotGiven = NOT_GIVEN,
        mms_transcoding: bool | NotGiven = NOT_GIVEN,
        name: str | NotGiven = NOT_GIVEN,
        number_pool_settings: Optional[NumberPoolSettingsParam] | NotGiven = NOT_GIVEN,
        url_shortener_settings: Optional[URLShortenerSettingsParam] | NotGiven = NOT_GIVEN,
        v1_secret: str | NotGiven = NOT_GIVEN,
        webhook_api_version: Literal["1", "2", "2010-04-01"] | NotGiven = NOT_GIVEN,
        webhook_failover_url: Optional[str] | NotGiven = NOT_GIVEN,
        webhook_url: Optional[str] | NotGiven = NOT_GIVEN,
        whitelisted_destinations: List[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MessagingProfileUpdateResponse:
        """
        Update a messaging profile

        Args:
          alpha_sender: The alphanumeric sender ID to use when sending to destinations that require an
              alphanumeric sender ID.

          daily_spend_limit: The maximum amount of money (in USD) that can be spent by this profile before
              midnight UTC.

          daily_spend_limit_enabled: Whether to enforce the value configured by `daily_spend_limit`.

          enabled: Specifies whether the messaging profile is enabled or not.

          mms_fall_back_to_sms: enables SMS fallback for MMS messages.

          mms_transcoding: enables automated resizing of MMS media.

          name: A user friendly name for the messaging profile.

          number_pool_settings: Number Pool allows you to send messages from a pool of numbers of different
              types, assigning weights to each type. The pool consists of all the long code
              and toll free numbers assigned to the messaging profile.

              To disable this feature, set the object field to `null`.

          url_shortener_settings: The URL shortener feature allows automatic replacement of URLs that were
              generated using a public URL shortener service. Some examples include bit.do,
              bit.ly, goo.gl, ht.ly, is.gd, ow.ly, rebrand.ly, t.co, tiny.cc, and tinyurl.com.
              Such URLs are replaced with with links generated by Telnyx. The use of custom
              links can improve branding and message deliverability.

              To disable this feature, set the object field to `null`.

          v1_secret: Secret used to authenticate with v1 endpoints.

          webhook_api_version: Determines which webhook format will be used, Telnyx API v1, v2, or a legacy
              2010-04-01 format.

          webhook_failover_url: The failover URL where webhooks related to this messaging profile will be sent
              if sending to the primary URL fails.

          webhook_url: The URL where webhooks related to this messaging profile will be sent.

          whitelisted_destinations: Destinations to which the messaging profile is allowed to send. The elements in
              the list must be valid ISO 3166-1 alpha-2 country codes. If set to `["*"]`, all
              destinations will be allowed.

              This field is required if the messaging profile doesn't have it defined yet.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._patch(
            f"/messaging_profiles/{id}",
            body=await async_maybe_transform(
                {
                    "alpha_sender": alpha_sender,
                    "daily_spend_limit": daily_spend_limit,
                    "daily_spend_limit_enabled": daily_spend_limit_enabled,
                    "enabled": enabled,
                    "mms_fall_back_to_sms": mms_fall_back_to_sms,
                    "mms_transcoding": mms_transcoding,
                    "name": name,
                    "number_pool_settings": number_pool_settings,
                    "url_shortener_settings": url_shortener_settings,
                    "v1_secret": v1_secret,
                    "webhook_api_version": webhook_api_version,
                    "webhook_failover_url": webhook_failover_url,
                    "webhook_url": webhook_url,
                    "whitelisted_destinations": whitelisted_destinations,
                },
                messaging_profile_update_params.MessagingProfileUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MessagingProfileUpdateResponse,
        )

    async def list(
        self,
        *,
        filter: messaging_profile_list_params.Filter | NotGiven = NOT_GIVEN,
        page: messaging_profile_list_params.Page | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MessagingProfileListResponse:
        """
        List messaging profiles

        Args:
          filter: Consolidated filter parameter (deepObject style). Originally: filter[name]

          page: Consolidated page parameter (deepObject style). Originally: page[number],
              page[size]

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/messaging_profiles",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "filter": filter,
                        "page": page,
                    },
                    messaging_profile_list_params.MessagingProfileListParams,
                ),
            ),
            cast_to=MessagingProfileListResponse,
        )

    async def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MessagingProfileDeleteResponse:
        """
        Delete a messaging profile

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._delete(
            f"/messaging_profiles/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MessagingProfileDeleteResponse,
        )

    async def list_phone_numbers(
        self,
        id: str,
        *,
        page: messaging_profile_list_phone_numbers_params.Page | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MessagingProfileListPhoneNumbersResponse:
        """
        List phone numbers associated with a messaging profile

        Args:
          page: Consolidated page parameter (deepObject style). Originally: page[number],
              page[size]

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/messaging_profiles/{id}/phone_numbers",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"page": page}, messaging_profile_list_phone_numbers_params.MessagingProfileListPhoneNumbersParams
                ),
            ),
            cast_to=MessagingProfileListPhoneNumbersResponse,
        )

    async def list_short_codes(
        self,
        id: str,
        *,
        page: messaging_profile_list_short_codes_params.Page | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MessagingProfileListShortCodesResponse:
        """
        List short codes associated with a messaging profile

        Args:
          page: Consolidated page parameter (deepObject style). Originally: page[number],
              page[size]

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/messaging_profiles/{id}/short_codes",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"page": page}, messaging_profile_list_short_codes_params.MessagingProfileListShortCodesParams
                ),
            ),
            cast_to=MessagingProfileListShortCodesResponse,
        )


class MessagingProfilesResourceWithRawResponse:
    def __init__(self, messaging_profiles: MessagingProfilesResource) -> None:
        self._messaging_profiles = messaging_profiles

        self.create = to_raw_response_wrapper(
            messaging_profiles.create,
        )
        self.retrieve = to_raw_response_wrapper(
            messaging_profiles.retrieve,
        )
        self.update = to_raw_response_wrapper(
            messaging_profiles.update,
        )
        self.list = to_raw_response_wrapper(
            messaging_profiles.list,
        )
        self.delete = to_raw_response_wrapper(
            messaging_profiles.delete,
        )
        self.list_phone_numbers = to_raw_response_wrapper(
            messaging_profiles.list_phone_numbers,
        )
        self.list_short_codes = to_raw_response_wrapper(
            messaging_profiles.list_short_codes,
        )

    @cached_property
    def autoresp_configs(self) -> AutorespConfigsResourceWithRawResponse:
        return AutorespConfigsResourceWithRawResponse(self._messaging_profiles.autoresp_configs)


class AsyncMessagingProfilesResourceWithRawResponse:
    def __init__(self, messaging_profiles: AsyncMessagingProfilesResource) -> None:
        self._messaging_profiles = messaging_profiles

        self.create = async_to_raw_response_wrapper(
            messaging_profiles.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            messaging_profiles.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            messaging_profiles.update,
        )
        self.list = async_to_raw_response_wrapper(
            messaging_profiles.list,
        )
        self.delete = async_to_raw_response_wrapper(
            messaging_profiles.delete,
        )
        self.list_phone_numbers = async_to_raw_response_wrapper(
            messaging_profiles.list_phone_numbers,
        )
        self.list_short_codes = async_to_raw_response_wrapper(
            messaging_profiles.list_short_codes,
        )

    @cached_property
    def autoresp_configs(self) -> AsyncAutorespConfigsResourceWithRawResponse:
        return AsyncAutorespConfigsResourceWithRawResponse(self._messaging_profiles.autoresp_configs)


class MessagingProfilesResourceWithStreamingResponse:
    def __init__(self, messaging_profiles: MessagingProfilesResource) -> None:
        self._messaging_profiles = messaging_profiles

        self.create = to_streamed_response_wrapper(
            messaging_profiles.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            messaging_profiles.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            messaging_profiles.update,
        )
        self.list = to_streamed_response_wrapper(
            messaging_profiles.list,
        )
        self.delete = to_streamed_response_wrapper(
            messaging_profiles.delete,
        )
        self.list_phone_numbers = to_streamed_response_wrapper(
            messaging_profiles.list_phone_numbers,
        )
        self.list_short_codes = to_streamed_response_wrapper(
            messaging_profiles.list_short_codes,
        )

    @cached_property
    def autoresp_configs(self) -> AutorespConfigsResourceWithStreamingResponse:
        return AutorespConfigsResourceWithStreamingResponse(self._messaging_profiles.autoresp_configs)


class AsyncMessagingProfilesResourceWithStreamingResponse:
    def __init__(self, messaging_profiles: AsyncMessagingProfilesResource) -> None:
        self._messaging_profiles = messaging_profiles

        self.create = async_to_streamed_response_wrapper(
            messaging_profiles.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            messaging_profiles.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            messaging_profiles.update,
        )
        self.list = async_to_streamed_response_wrapper(
            messaging_profiles.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            messaging_profiles.delete,
        )
        self.list_phone_numbers = async_to_streamed_response_wrapper(
            messaging_profiles.list_phone_numbers,
        )
        self.list_short_codes = async_to_streamed_response_wrapper(
            messaging_profiles.list_short_codes,
        )

    @cached_property
    def autoresp_configs(self) -> AsyncAutorespConfigsResourceWithStreamingResponse:
        return AsyncAutorespConfigsResourceWithStreamingResponse(self._messaging_profiles.autoresp_configs)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = [
    "PhoneNumbersJob",
    "FailedOperation",
    "FailedOperationError",
    "FailedOperationErrorMeta",
    "FailedOperationErrorSource",
    "PendingOperation",
    "PhoneNumber",
    "SuccessfulOperation",
]


class FailedOperationErrorMeta(BaseModel):
    url: Optional[str] = None
    """URL with additional information on the error."""


class FailedOperationErrorSource(BaseModel):
    parameter: Optional[str] = None
    """Indicates which query parameter caused the error."""

    pointer: Optional[str] = None
    """JSON pointer (RFC6901) to the offending entity."""


class FailedOperationError(BaseModel):
    code: str

    title: str

    detail: Optional[str] = None

    meta: Optional[FailedOperationErrorMeta] = None

    source: Optional[FailedOperationErrorSource] = None


class FailedOperation(BaseModel):
    id: Optional[str] = None
    """The phone number's ID"""

    errors: Optional[List[FailedOperationError]] = None

    phone_number: Optional[str] = None
    """The phone number in e164 format."""


class PendingOperation(BaseModel):
    id: Optional[str] = None
    """The phone number's ID"""

    phone_number: Optional[str] = None
    """The phone number in e164 format."""


class PhoneNumber(BaseModel):
    id: Optional[str] = None
    """The phone number's ID"""

    phone_number: Optional[str] = None
    """The phone number in e164 format."""


class SuccessfulOperation(BaseModel):
    id: Optional[str] = None
    """The phone number's ID"""

    phone_number: Optional[str] = None
    """The phone number in e164 format."""


class PhoneNumbersJob(BaseModel):
    id: Optional[str] = None
    """Identifies the resource."""

    created_at: Optional[str] = None
    """ISO 8601 formatted date indicating when the resource was created."""

    etc: Optional[datetime] = None
    """
    ISO 8601 formatted date indicating when the estimated time of completion of the
    background job.
    """

    failed_operations: Optional[List[FailedOperation]] = None

    pending_operations: Optional[List[PendingOperation]] = None

    phone_numbers: Optional[List[PhoneNumber]] = None

    record_type: Optional[str] = None
    """Identifies the type of the resource."""

    status: Optional[Literal["pending", "in_progress", "completed", "failed", "expired"]] = None
    """Indicates the completion status of the background update."""

    successful_operations: Optional[List[SuccessfulOperation]] = None

    type: Optional[Literal["update_emergency_settings", "delete_phone_numbers", "update_phone_numbers"]] = None
    """Identifies the type of the background job."""

    updated_at: Optional[str] = None
    """ISO 8601 formatted date indicating when the resource was updated."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from ..._models import BaseModel
from ..verification import Verification

__all__ = ["ByPhoneNumberListResponse", "Meta"]


class Meta(BaseModel):
    page_number: Optional[int] = None

    page_size: Optional[int] = None

    total_pages: Optional[int] = None

    total_results: Optional[int] = None


class ByPhoneNumberListResponse(BaseModel):
    data: List[Verification]

    meta: Meta



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._types import FileTypes
from .._utils import PropertyInfo

__all__ = ["ClientPutObjectParams"]


class ClientPutObjectParams(TypedDict, total=False):
    bucket_name: Required[Annotated[str, PropertyInfo(alias="bucketName")]]

    body: Required[FileTypes]

    part_number: Annotated[str, PropertyInfo(alias="partNumber")]

    upload_id: Annotated[str, PropertyInfo(alias="uploadId")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.external_connections import release_list_params
from ...types.external_connections.release_list_response import ReleaseListResponse
from ...types.external_connections.release_retrieve_response import ReleaseRetrieveResponse

__all__ = ["ReleasesResource", "AsyncReleasesResource"]


class ReleasesResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ReleasesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return ReleasesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ReleasesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return ReleasesResourceWithStreamingResponse(self)

    def retrieve(
        self,
        release_id: str,
        *,
        id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ReleaseRetrieveResponse:
        """
        Return the details of a Release request and its phone numbers.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        if not release_id:
            raise ValueError(f"Expected a non-empty value for `release_id` but received {release_id!r}")
        return self._get(
            f"/external_connections/{id}/releases/{release_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ReleaseRetrieveResponse,
        )

    def list(
        self,
        id: str,
        *,
        filter: release_list_params.Filter | NotGiven = NOT_GIVEN,
        page: release_list_params.Page | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ReleaseListResponse:
        """Returns a list of your Releases for the given external connection.

        These are
        automatically created when you change the `connection_id` of a phone number that
        is currently on Microsoft Teams.

        Args:
          filter: Filter parameter for releases (deepObject style). Supports filtering by status,
              civic_address_id, location_id, and phone_number with eq/contains operations.

          page: Consolidated page parameter (deepObject style). Originally: page[size],
              page[number]

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/external_connections/{id}/releases",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "filter": filter,
                        "page": page,
                    },
                    release_list_params.ReleaseListParams,
                ),
            ),
            cast_to=ReleaseListResponse,
        )


class AsyncReleasesResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncReleasesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return AsyncReleasesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncReleasesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return AsyncReleasesResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        release_id: str,
        *,
        id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ReleaseRetrieveResponse:
        """
        Return the details of a Release request and its phone numbers.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        if not release_id:
            raise ValueError(f"Expected a non-empty value for `release_id` but received {release_id!r}")
        return await self._get(
            f"/external_connections/{id}/releases/{release_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ReleaseRetrieveResponse,
        )

    async def list(
        self,
        id: str,
        *,
        filter: release_list_params.Filter | NotGiven = NOT_GIVEN,
        page: release_list_params.Page | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ReleaseListResponse:
        """Returns a list of your Releases for the given external connection.

        These are
        automatically created when you change the `connection_id` of a phone number that
        is currently on Microsoft Teams.

        Args:
          filter: Filter parameter for releases (deepObject style). Supports filtering by status,
              civic_address_id, location_id, and phone_number with eq/contains operations.

          page: Consolidated page parameter (deepObject style). Originally: page[size],
              page[number]

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/external_connections/{id}/releases",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "filter": filter,
                        "page": page,
                    },
                    release_list_params.ReleaseListParams,
                ),
            ),
            cast_to=ReleaseListResponse,
        )


class ReleasesResourceWithRawResponse:
    def __init__(self, releases: ReleasesResource) -> None:
        self._releases = releases

        self.retrieve = to_raw_response_wrapper(
            releases.retrieve,
        )
        self.list = to_raw_response_wrapper(
            releases.list,
        )


class AsyncReleasesResourceWithRawResponse:
    def __init__(self, releases: AsyncReleasesResource) -> None:
        self._releases = releases

        self.retrieve = async_to_raw_response_wrapper(
            releases.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            releases.list,
        )


class ReleasesResourceWithStreamingResponse:
    def __init__(self, releases: ReleasesResource) -> None:
        self._releases = releases

        self.retrieve = to_streamed_response_wrapper(
            releases.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            releases.list,
        )


class AsyncReleasesResourceWithStreamingResponse:
    def __init__(self, releases: AsyncReleasesResource) -> None:
        self._releases = releases

        self.retrieve = async_to_streamed_response_wrapper(
            releases.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            releases.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel
from .pagination_meta import PaginationMeta
from .doc_service_document import DocServiceDocument

__all__ = ["DocumentListResponse"]


class DocumentListResponse(BaseModel):
    data: Optional[List[DocServiceDocument]] = None

    meta: Optional[PaginationMeta] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["InsightGroupInsightGroupsParams"]


class InsightGroupInsightGroupsParams(TypedDict, total=False):
    name: Required[str]

    description: str

    webhook: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.queues import call_list_params
from ...types.queues.call_list_response import CallListResponse
from ...types.queues.call_retrieve_response import CallRetrieveResponse

__all__ = ["CallsResource", "AsyncCallsResource"]


class CallsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> CallsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return CallsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> CallsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return CallsResourceWithStreamingResponse(self)

    def retrieve(
        self,
        call_control_id: str,
        *,
        queue_name: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> CallRetrieveResponse:
        """
        Retrieve an existing call from an existing queue

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not queue_name:
            raise ValueError(f"Expected a non-empty value for `queue_name` but received {queue_name!r}")
        if not call_control_id:
            raise ValueError(f"Expected a non-empty value for `call_control_id` but received {call_control_id!r}")
        return self._get(
            f"/queues/{queue_name}/calls/{call_control_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=CallRetrieveResponse,
        )

    def list(
        self,
        queue_name: str,
        *,
        page: call_list_params.Page | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> CallListResponse:
        """
        Retrieve the list of calls in an existing queue

        Args:
          page: Consolidated page parameter (deepObject style). Originally: page[after],
              page[before], page[limit], page[size], page[number]

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not queue_name:
            raise ValueError(f"Expected a non-empty value for `queue_name` but received {queue_name!r}")
        return self._get(
            f"/queues/{queue_name}/calls",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"page": page}, call_list_params.CallListParams),
            ),
            cast_to=CallListResponse,
        )


class AsyncCallsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncCallsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return AsyncCallsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncCallsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return AsyncCallsResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        call_control_id: str,
        *,
        queue_name: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> CallRetrieveResponse:
        """
        Retrieve an existing call from an existing queue

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not queue_name:
            raise ValueError(f"Expected a non-empty value for `queue_name` but received {queue_name!r}")
        if not call_control_id:
            raise ValueError(f"Expected a non-empty value for `call_control_id` but received {call_control_id!r}")
        return await self._get(
            f"/queues/{queue_name}/calls/{call_control_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=CallRetrieveResponse,
        )

    async def list(
        self,
        queue_name: str,
        *,
        page: call_list_params.Page | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> CallListResponse:
        """
        Retrieve the list of calls in an existing queue

        Args:
          page: Consolidated page parameter (deepObject style). Originally: page[after],
              page[before], page[limit], page[size], page[number]

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not queue_name:
            raise ValueError(f"Expected a non-empty value for `queue_name` but received {queue_name!r}")
        return await self._get(
            f"/queues/{queue_name}/calls",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"page": page}, call_list_params.CallListParams),
            ),
            cast_to=CallListResponse,
        )


class CallsResourceWithRawResponse:
    def __init__(self, calls: CallsResource) -> None:
        self._calls = calls

        self.retrieve = to_raw_response_wrapper(
            calls.retrieve,
        )
        self.list = to_raw_response_wrapper(
            calls.list,
        )


class AsyncCallsResourceWithRawResponse:
    def __init__(self, calls: AsyncCallsResource) -> None:
        self._calls = calls

        self.retrieve = async_to_raw_response_wrapper(
            calls.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            calls.list,
        )


class CallsResourceWithStreamingResponse:
    def __init__(self, calls: CallsResource) -> None:
        self._calls = calls

        self.retrieve = to_streamed_response_wrapper(
            calls.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            calls.list,
        )


class AsyncCallsResourceWithStreamingResponse:
    def __init__(self, calls: AsyncCallsResource) -> None:
        self._calls = calls

        self.retrieve = async_to_streamed_response_wrapper(
            calls.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            calls.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel

__all__ = ["VoiceSettings"]


class VoiceSettings(BaseModel):
    voice: str
    """The voice to be used by the voice assistant.

    Check the full list of
    [available voices](https://developers.telnyx.com/api/call-control/list-text-to-speech-voices)
    via our voices API. To use ElevenLabs, you must reference your ElevenLabs API
    key as an integration secret under the `api_key_ref` field. See
    [integration secrets documentation](https://developers.telnyx.com/api/secrets-manager/integration-secrets/create-integration-secret)
    for details. For Telnyx voices, use `Telnyx.<model_id>.<voice_id>` (e.g.
    Telnyx.KokoroTTS.af_heart)
    """

    api_key_ref: Optional[str] = None
    """
    The `identifier` for an integration secret
    [/v2/integration_secrets](https://developers.telnyx.com/api/secrets-manager/integration-secrets/create-integration-secret)
    that refers to your ElevenLabs API key. Warning: Free plans are unlikely to work
    with this integration.
    """

    voice_speed: Optional[float] = None
    """The speed of the voice in the range [0.25, 2.0].

    1.0 is deafult speed. Larger numbers make the voice faster, smaller numbers make
    it slower. This is only applicable for Telnyx Natural voices.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import httpx
import pytest
from respx import MockRouter

from telnyx import Telnyx, AsyncTelnyx
from tests.utils import assert_matches_type
from telnyx.types import (
    ListBucketsResponse,
    ListObjectsResponse,
)
from telnyx._response import (
    BinaryAPIResponse,
    AsyncBinaryAPIResponse,
    StreamedBinaryAPIResponse,
    AsyncStreamedBinaryAPIResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestClient:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create_bucket(self, client: Telnyx) -> None:
        client_ = client.create_bucket(
            bucket_name="mybucket",
        )
        assert client_ is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create_bucket_with_all_params(self, client: Telnyx) -> None:
        client_ = client.create_bucket(
            bucket_name="mybucket",
            location_constraint="LocationConstraint",
        )
        assert client_ is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_create_bucket(self, client: Telnyx) -> None:
        response = client.with_raw_response.create_bucket(
            bucket_name="mybucket",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        client_ = response.parse()
        assert client_ is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_create_bucket(self, client: Telnyx) -> None:
        with client.with_streaming_response.create_bucket(
            bucket_name="mybucket",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            client_ = response.parse()
            assert client_ is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_create_bucket(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `bucket_name` but received ''"):
            client.with_raw_response.create_bucket(
                bucket_name="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_delete_bucket(self, client: Telnyx) -> None:
        client_ = client.delete_bucket(
            "bucketName",
        )
        assert client_ is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_delete_bucket(self, client: Telnyx) -> None:
        response = client.with_raw_response.delete_bucket(
            "bucketName",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        client_ = response.parse()
        assert client_ is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_delete_bucket(self, client: Telnyx) -> None:
        with client.with_streaming_response.delete_bucket(
            "bucketName",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            client_ = response.parse()
            assert client_ is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_delete_bucket(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `bucket_name` but received ''"):
            client.with_raw_response.delete_bucket(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_delete_object(self, client: Telnyx) -> None:
        client_ = client.delete_object(
            object_name="x",
            bucket_name="bucketName",
        )
        assert client_ is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_delete_object(self, client: Telnyx) -> None:
        response = client.with_raw_response.delete_object(
            object_name="x",
            bucket_name="bucketName",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        client_ = response.parse()
        assert client_ is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_delete_object(self, client: Telnyx) -> None:
        with client.with_streaming_response.delete_object(
            object_name="x",
            bucket_name="bucketName",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            client_ = response.parse()
            assert client_ is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_delete_object(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `bucket_name` but received ''"):
            client.with_raw_response.delete_object(
                object_name="x",
                bucket_name="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `object_name` but received ''"):
            client.with_raw_response.delete_object(
                object_name="",
                bucket_name="bucketName",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_delete_objects(self, client: Telnyx) -> None:
        client_ = client.delete_objects(
            bucket_name="bucketName",
            delete=True,
            body=[{}],
        )
        assert_matches_type(object, client_, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_delete_objects(self, client: Telnyx) -> None:
        response = client.with_raw_response.delete_objects(
            bucket_name="bucketName",
            delete=True,
            body=[{}],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        client_ = response.parse()
        assert_matches_type(object, client_, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_delete_objects(self, client: Telnyx) -> None:
        with client.with_streaming_response.delete_objects(
            bucket_name="bucketName",
            delete=True,
            body=[{}],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            client_ = response.parse()
            assert_matches_type(object, client_, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_delete_objects(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `bucket_name` but received ''"):
            client.with_raw_response.delete_objects(
                bucket_name="",
                delete=True,
                body=[{}],
            )

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_method_get_object(self, client: Telnyx, respx_mock: MockRouter) -> None:
        respx_mock.get("/bucketName/x").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        client_ = client.get_object(
            object_name="x",
            bucket_name="bucketName",
        )
        assert client_.is_closed
        assert client_.json() == {"foo": "bar"}
        assert cast(Any, client_.is_closed) is True
        assert isinstance(client_, BinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_method_get_object_with_all_params(self, client: Telnyx, respx_mock: MockRouter) -> None:
        respx_mock.get("/bucketName/x").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        client_ = client.get_object(
            object_name="x",
            bucket_name="bucketName",
            upload_id="uploadId",
        )
        assert client_.is_closed
        assert client_.json() == {"foo": "bar"}
        assert cast(Any, client_.is_closed) is True
        assert isinstance(client_, BinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_raw_response_get_object(self, client: Telnyx, respx_mock: MockRouter) -> None:
        respx_mock.get("/bucketName/x").mock(return_value=httpx.Response(200, json={"foo": "bar"}))

        client_ = client.with_raw_response.get_object(
            object_name="x",
            bucket_name="bucketName",
        )

        assert client_.is_closed is True
        assert client_.http_request.headers.get("X-Stainless-Lang") == "python"
        assert client_.json() == {"foo": "bar"}
        assert isinstance(client_, BinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_streaming_response_get_object(self, client: Telnyx, respx_mock: MockRouter) -> None:
        respx_mock.get("/bucketName/x").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        with client.with_streaming_response.get_object(
            object_name="x",
            bucket_name="bucketName",
        ) as client_:
            assert not client_.is_closed
            assert client_.http_request.headers.get("X-Stainless-Lang") == "python"

            assert client_.json() == {"foo": "bar"}
            assert cast(Any, client_.is_closed) is True
            assert isinstance(client_, StreamedBinaryAPIResponse)

        assert cast(Any, client_.is_closed) is True

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_path_params_get_object(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `bucket_name` but received ''"):
            client.with_raw_response.get_object(
                object_name="x",
                bucket_name="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `object_name` but received ''"):
            client.with_raw_response.get_object(
                object_name="",
                bucket_name="bucketName",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_buckets(self, client: Telnyx) -> None:
        client_ = client.list_buckets()
        assert_matches_type(ListBucketsResponse, client_, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list_buckets(self, client: Telnyx) -> None:
        response = client.with_raw_response.list_buckets()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        client_ = response.parse()
        assert_matches_type(ListBucketsResponse, client_, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list_buckets(self, client: Telnyx) -> None:
        with client.with_streaming_response.list_buckets() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            client_ = response.parse()
            assert_matches_type(ListBucketsResponse, client_, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_objects(self, client: Telnyx) -> None:
        client_ = client.list_objects(
            bucket_name="xxxx",
        )
        assert_matches_type(ListObjectsResponse, client_, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_objects_with_all_params(self, client: Telnyx) -> None:
        client_ = client.list_objects(
            bucket_name="xxxx",
            list_type=2,
        )
        assert_matches_type(ListObjectsResponse, client_, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list_objects(self, client: Telnyx) -> None:
        response = client.with_raw_response.list_objects(
            bucket_name="xxxx",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        client_ = response.parse()
        assert_matches_type(ListObjectsResponse, client_, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list_objects(self, client: Telnyx) -> None:
        with client.with_streaming_response.list_objects(
            bucket_name="xxxx",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            client_ = response.parse()
            assert_matches_type(ListObjectsResponse, client_, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_list_objects(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `bucket_name` but received ''"):
            client.with_raw_response.list_objects(
                bucket_name="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_put_object(self, client: Telnyx) -> None:
        client_ = client.put_object(
            object_name="x",
            bucket_name="bucketName",
            body=b"raw file contents",
        )
        assert client_ is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_put_object_with_all_params(self, client: Telnyx) -> None:
        client_ = client.put_object(
            object_name="x",
            bucket_name="bucketName",
            body=b"raw file contents",
            part_number="partNumber",
            upload_id="uploadId",
        )
        assert client_ is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_put_object(self, client: Telnyx) -> None:
        response = client.with_raw_response.put_object(
            object_name="x",
            bucket_name="bucketName",
            body=b"raw file contents",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        client_ = response.parse()
        assert client_ is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_put_object(self, client: Telnyx) -> None:
        with client.with_streaming_response.put_object(
            object_name="x",
            bucket_name="bucketName",
            body=b"raw file contents",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            client_ = response.parse()
            assert client_ is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_put_object(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `bucket_name` but received ''"):
            client.with_raw_response.put_object(
                object_name="x",
                bucket_name="",
                body=b"raw file contents",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `object_name` but received ''"):
            client.with_raw_response.put_object(
                object_name="",
                bucket_name="bucketName",
                body=b"raw file contents",
            )


class TestAsyncClient:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create_bucket(self, async_client: AsyncTelnyx) -> None:
        client = await async_client.create_bucket(
            bucket_name="mybucket",
        )
        assert client is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create_bucket_with_all_params(self, async_client: AsyncTelnyx) -> None:
        client = await async_client.create_bucket(
            bucket_name="mybucket",
            location_constraint="LocationConstraint",
        )
        assert client is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_create_bucket(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.with_raw_response.create_bucket(
            bucket_name="mybucket",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        client = await response.parse()
        assert client is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_create_bucket(self, async_client: AsyncTelnyx) -> None:
        async with async_client.with_streaming_response.create_bucket(
            bucket_name="mybucket",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            client = await response.parse()
            assert client is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_create_bucket(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `bucket_name` but received ''"):
            await async_client.with_raw_response.create_bucket(
                bucket_name="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_delete_bucket(self, async_client: AsyncTelnyx) -> None:
        client = await async_client.delete_bucket(
            "bucketName",
        )
        assert client is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_delete_bucket(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.with_raw_response.delete_bucket(
            "bucketName",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        client = await response.parse()
        assert client is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_delete_bucket(self, async_client: AsyncTelnyx) -> None:
        async with async_client.with_streaming_response.delete_bucket(
            "bucketName",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            client = await response.parse()
            assert client is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_delete_bucket(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `bucket_name` but received ''"):
            await async_client.with_raw_response.delete_bucket(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_delete_object(self, async_client: AsyncTelnyx) -> None:
        client = await async_client.delete_object(
            object_name="x",
            bucket_name="bucketName",
        )
        assert client is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_delete_object(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.with_raw_response.delete_object(
            object_name="x",
            bucket_name="bucketName",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        client = await response.parse()
        assert client is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_delete_object(self, async_client: AsyncTelnyx) -> None:
        async with async_client.with_streaming_response.delete_object(
            object_name="x",
            bucket_name="bucketName",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            client = await response.parse()
            assert client is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_delete_object(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `bucket_name` but received ''"):
            await async_client.with_raw_response.delete_object(
                object_name="x",
                bucket_name="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `object_name` but received ''"):
            await async_client.with_raw_response.delete_object(
                object_name="",
                bucket_name="bucketName",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_delete_objects(self, async_client: AsyncTelnyx) -> None:
        client = await async_client.delete_objects(
            bucket_name="bucketName",
            delete=True,
            body=[{}],
        )
        assert_matches_type(object, client, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_delete_objects(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.with_raw_response.delete_objects(
            bucket_name="bucketName",
            delete=True,
            body=[{}],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        client = await response.parse()
        assert_matches_type(object, client, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_delete_objects(self, async_client: AsyncTelnyx) -> None:
        async with async_client.with_streaming_response.delete_objects(
            bucket_name="bucketName",
            delete=True,
            body=[{}],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            client = await response.parse()
            assert_matches_type(object, client, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_delete_objects(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `bucket_name` but received ''"):
            await async_client.with_raw_response.delete_objects(
                bucket_name="",
                delete=True,
                body=[{}],
            )

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_method_get_object(self, async_client: AsyncTelnyx, respx_mock: MockRouter) -> None:
        respx_mock.get("/bucketName/x").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        client = await async_client.get_object(
            object_name="x",
            bucket_name="bucketName",
        )
        assert client.is_closed
        assert await client.json() == {"foo": "bar"}
        assert cast(Any, client.is_closed) is True
        assert isinstance(client, AsyncBinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_method_get_object_with_all_params(self, async_client: AsyncTelnyx, respx_mock: MockRouter) -> None:
        respx_mock.get("/bucketName/x").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        client = await async_client.get_object(
            object_name="x",
            bucket_name="bucketName",
            upload_id="uploadId",
        )
        assert client.is_closed
        assert await client.json() == {"foo": "bar"}
        assert cast(Any, client.is_closed) is True
        assert isinstance(client, AsyncBinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_raw_response_get_object(self, async_client: AsyncTelnyx, respx_mock: MockRouter) -> None:
        respx_mock.get("/bucketName/x").mock(return_value=httpx.Response(200, json={"foo": "bar"}))

        client = await async_client.with_raw_response.get_object(
            object_name="x",
            bucket_name="bucketName",
        )

        assert client.is_closed is True
        assert client.http_request.headers.get("X-Stainless-Lang") == "python"
        assert await client.json() == {"foo": "bar"}
        assert isinstance(client, AsyncBinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_streaming_response_get_object(self, async_client: AsyncTelnyx, respx_mock: MockRouter) -> None:
        respx_mock.get("/bucketName/x").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        async with async_client.with_streaming_response.get_object(
            object_name="x",
            bucket_name="bucketName",
        ) as client:
            assert not client.is_closed
            assert client.http_request.headers.get("X-Stainless-Lang") == "python"

            assert await client.json() == {"foo": "bar"}
            assert cast(Any, client.is_closed) is True
            assert isinstance(client, AsyncStreamedBinaryAPIResponse)

        assert cast(Any, client.is_closed) is True

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_path_params_get_object(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `bucket_name` but received ''"):
            await async_client.with_raw_response.get_object(
                object_name="x",
                bucket_name="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `object_name` but received ''"):
            await async_client.with_raw_response.get_object(
                object_name="",
                bucket_name="bucketName",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_buckets(self, async_client: AsyncTelnyx) -> None:
        client = await async_client.list_buckets()
        assert_matches_type(ListBucketsResponse, client, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list_buckets(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.with_raw_response.list_buckets()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        client = await response.parse()
        assert_matches_type(ListBucketsResponse, client, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list_buckets(self, async_client: AsyncTelnyx) -> None:
        async with async_client.with_streaming_response.list_buckets() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            client = await response.parse()
            assert_matches_type(ListBucketsResponse, client, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_objects(self, async_client: AsyncTelnyx) -> None:
        client = await async_client.list_objects(
            bucket_name="xxxx",
        )
        assert_matches_type(ListObjectsResponse, client, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_objects_with_all_params(self, async_client: AsyncTelnyx) -> None:
        client = await async_client.list_objects(
            bucket_name="xxxx",
            list_type=2,
        )
        assert_matches_type(ListObjectsResponse, client, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list_objects(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.with_raw_response.list_objects(
            bucket_name="xxxx",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        client = await response.parse()
        assert_matches_type(ListObjectsResponse, client, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list_objects(self, async_client: AsyncTelnyx) -> None:
        async with async_client.with_streaming_response.list_objects(
            bucket_name="xxxx",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            client = await response.parse()
            assert_matches_type(ListObjectsResponse, client, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_list_objects(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `bucket_name` but received ''"):
            await async_client.with_raw_response.list_objects(
                bucket_name="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_put_object(self, async_client: AsyncTelnyx) -> None:
        client = await async_client.put_object(
            object_name="x",
            bucket_name="bucketName",
            body=b"raw file contents",
        )
        assert client is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_put_object_with_all_params(self, async_client: AsyncTelnyx) -> None:
        client = await async_client.put_object(
            object_name="x",
            bucket_name="bucketName",
            body=b"raw file contents",
            part_number="partNumber",
            upload_id="uploadId",
        )
        assert client is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_put_object(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.with_raw_response.put_object(
            object_name="x",
            bucket_name="bucketName",
            body=b"raw file contents",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        client = await response.parse()
        assert client is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_put_object(self, async_client: AsyncTelnyx) -> None:
        async with async_client.with_streaming_response.put_object(
            object_name="x",
            bucket_name="bucketName",
            body=b"raw file contents",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            client = await response.parse()
            assert client is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_put_object(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `bucket_name` but received ''"):
            await async_client.with_raw_response.put_object(
                object_name="x",
                bucket_name="",
                body=b"raw file contents",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `object_name` but received ''"):
            await async_client.with_raw_response.put_object(
                object_name="",
                bucket_name="bucketName",
                body=b"raw file contents",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["ClientDeleteObjectsParams", "Body"]


class ClientDeleteObjectsParams(TypedDict, total=False):
    delete: Required[Literal[True]]

    body: Required[Iterable[Body]]


class Body(TypedDict, total=False):
    key: Annotated[str, PropertyInfo(alias="Key")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["ClientListObjectsParams"]


class ClientListObjectsParams(TypedDict, total=False):
    list_type: Annotated[Literal[2], PropertyInfo(alias="list-type")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["ListBucketsResponse", "Bucket"]


class Bucket(BaseModel):
    creation_date: Optional[datetime] = FieldInfo(alias="CreationDate", default=None)

    name: Optional[str] = FieldInfo(alias="Name", default=None)


class ListBucketsResponse(BaseModel):
    buckets: Optional[List[Bucket]] = FieldInfo(alias="Buckets", default=None)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import TypedDict

__all__ = ["ActionMuteParams"]


class ActionMuteParams(TypedDict, total=False):
    call_control_ids: List[str]
    """Array of unique identifiers and tokens for controlling the call.

    When empty all participants will be muted.
    """
